==> comedi-0.5.4.tgz: comedi-0.5.4/module/dummy.c <==
/*
 * dummy driver
 * David A. Schleef
 */

#include <linux/kernel.h>
#include <linux/sched.h>
#include <linux/mm.h>
#include <linux/malloc.h>
#include <linux/errno.h>
#include <linux/ioport.h>
#include <linux/delay.h>
#include <linux/interrupt.h>
#include <linux/timex.h>
#include <linux/timer.h>
#include <asm/io.h>
#include <comedi_module.h>

/* this structure is for data unique to this hardware driver.  If
   several hardware drivers keep similar information in this structure,
   feel free to suggest moving the variable to the comedi_device struct.  */
typedef struct{
	int data;
}dummy_private;
#define devpriv ((dummy_private *)dev->private)

comedi_devinit dummy_init;
static int dummy_rem(comedi_device *dev);

static int dummy_input(comedi_device *dev,comedi_trig *it);
static int dummy_output(comedi_device *dev,comedi_trig *it);

int dummy_init(comedi_device *dev,comedi_devconfig *it)
{
/* there is a *_init() function for each hardware driver installed.
   Each one is called in sequence.
   if it->name is a device that this hardware driver supports, we try
   to initialize it.  If everything works, return a 1.  If there is
   an error, return the error.  If we do not match it->name, return a
   0 so that the next *_init() function can be tried. */

/* *dev is zeroed except for dev->minor, which contains the minor
   number being used.  *it has configuration information (not really
   used here--see other drivers.)  this function is responsible for
   filling the rest of *dev. */

#if DEBUG
	printk("testing dummy\n");
#endif
	if(strcmp("dummy",it->name)){
#if DEBUG
	printk("tested false\n");
#endif
		return 0;
	}

#if DEBUG
	printk("tested ok\n");
#endif
	printk("comedi%d: dummy: ",dev->minor);
	
	/* this is an appropriate place to put probe and initialization
	   code.  remember to fill in dev->iobase and friends. */
	dev->board_name="dummy";
	dev->driver_name="dummy";
	dev->chan=2;

	dev->private=kmalloc(sizeof(dummy_private)+
		dev->chan*sizeof(comedi_chinfo),GFP_KERNEL);
	if(!dev->private)return -ENOMEM;
#if DEBUG
	printk("malloc ok\n");
#endif
	memset(dev->private,0,sizeof(dummy_private)+
		dev->chan*sizeof(comedi_chinfo));
#if DEBUG
	printk("memset ok\n");
#endif

	dev->chinfo=dev->private+sizeof(dummy_private);

	dev->chinfo[0].itrig=dummy_input;
	addparam(&dev->chinfo[0].paramlist,COMEDI_BITS,COMEDI_RDONLY,16);
	addparam(&dev->chinfo[0].paramlist,COMEDI_MAXDATA,COMEDI_RDONLY,0xffff);
	addparam(&dev->chinfo[0].paramlist,COMEDI_AD,COMEDI_RDONLY,
		COMEDI_AD_ANALOG);
	addparam(&dev->chinfo[0].paramlist,COMEDI_IO,COMEDI_RDONLY,
		COMEDI_IO_INPUT);

	dev->chinfo[1].itrig=dummy_output;
	addparam(&dev->chinfo[1].paramlist,COMEDI_BITS,COMEDI_RDONLY,16);
	addparam(&dev->chinfo[1].paramlist,COMEDI_MAXDATA,COMEDI_RDONLY,0xffff);
	addparam(&dev->chinfo[1].paramlist,COMEDI_AD,COMEDI_RDONLY,
		COMEDI_AD_ANALOG);
	addparam(&dev->chinfo[1].paramlist,COMEDI_IO,COMEDI_RDONLY,
		COMEDI_IO_OUTPUT);

#if DEBUG
	printk("addparam ok\n");
#endif
	comedi_initbuf(&dev->rdbuf);
#if DEBUG
	printk("initbuf ok\n");
#endif

	dev->rem=dummy_rem;

	return 1;
}


static int dummy_rem(comedi_device *dev)
{
	printk("comedi%d: dummy: remove\n",dev->minor);
	
	kfree(dev->private);

	comedi_freebuf(&dev->rdbuf);
	
	return 0;
}

static int dummy_input(comedi_device *dev,comedi_trig *it)
{
	if(it->trigsrc!=COMEDI_TRIGNOW)return -EINVAL;
	it->n=1;
	it->data=devpriv->data;

	return 0;
}

static int dummy_output(comedi_device *dev,comedi_trig *it)
{
	devpriv->data=it->data;

	if(it->trigsrc!=COMEDI_TRIGNOW)return -EINVAL;
	it->n=1;
	devpriv->data=it->data;

	return 0;
}

==> comedi-0.6.0.tgz: comedi-0.6.0/module/dummy.c <==
/*
 * dummy driver
 * David A. Schleef
 */

#include <linux/kernel.h>
#include <linux/sched.h>
#include <linux/mm.h>
#include <linux/malloc.h>
#include <linux/errno.h>
#include <linux/ioport.h>
#include <linux/delay.h>
#include <linux/interrupt.h>
#include <linux/timex.h>
#include <linux/timer.h>
#include <asm/io.h>
#include <comedi_module.h>

/* this structure is for data unique to this hardware driver.  If
   several hardware drivers keep similar information in this structure,
   feel free to suggest moving the variable to the comedi_device struct.  */
typedef struct{
	int data;
}dummy_private;
#define devpriv ((dummy_private *)dev->private)

comedi_devinit dummy_init;
static int dummy_rem(comedi_device *dev);

static int dummy_ai(comedi_device *dev,comedi_trig *it);
static int dummy_ao(comedi_device *dev,comedi_trig *it);

int dummy_init(comedi_device *dev,comedi_devconfig *it)
{
	comedi_subdevice *s;

/* there is a *_init() function for each hardware driver installed.
   Each one is called in sequence.
   if it->name is a device that this hardware driver supports, we try
   to initialize it.  If everything works, return a 1.  If there is
   an error, return the error.  If we do not match it->name, return a
   0 so that the next *_init() function can be tried. */

/* *dev is zeroed except for dev->minor, which contains the minor
   number being used.  *it has configuration information (not really
   used here--see other drivers.)  this function is responsible for
   filling the rest of *dev. */

#if DEBUG
	printk("testing dummy\n");
#endif
	if(strcmp("dummy",it->board_name)){
#if DEBUG
		printk("tested false\n");
#endif
		return 0;
	}

#if DEBUG
	printk("tested ok\n");
#endif
	printk("comedi%d: dummy: ",dev->minor);
	
	/* this is an appropriate place to put probe and initialization
	   code.  remember to fill in dev->iobase and friends. */
	dev->board_name="dummy";
	dev->driver_name="dummy";

	dev->private=kmalloc(sizeof(dummy_private),GFP_KERNEL);
	if(!dev->private)return -ENOMEM;
#if DEBUG
	printk("malloc ok\n");
#endif
	memset(dev->private,0,sizeof(dummy_private));
#if DEBUG
	printk("memset ok\n");
#endif
	dev->n_subdevices=2;
	
	dev->subdevices=kmalloc(2*sizeof(comedi_subdevice),GFP_KERNEL);
	if(!dev->subdevices)return -ENOMEM;
	memset(dev->subdevices,0,2*sizeof(comedi_subdevice));

	/* analog input subdevice */
	s=dev->subdevices+0;
	s->type=COMEDI_SUBD_AI;
	s->n_chan=1;
	s->maxdata=0xffff;
	s->trig=dummy_ai;
	
	/* analog output subdevice */
	s=dev->subdevices+1;
	s->type=COMEDI_SUBD_AO;
	s->n_chan=1;
	s->maxdata=0xffff;
	s->trig=dummy_ao;
	
#if DEBUG
	printk("addparam ok\n");
#endif
	comedi_initbuf(&dev->rdbuf);
#if DEBUG
	printk("initbuf ok\n");
#endif

	dev->rem=dummy_rem;

	return 1;
}


static int dummy_rem(comedi_device *dev)
{
	printk("comedi%d: dummy: remove\n",dev->minor);
	
	kfree(dev->private);

	comedi_freebuf(&dev->rdbuf);
	
	return 0;
}

static int dummy_ai(comedi_device *dev,comedi_trig *it)
{
	it->data[0]=devpriv->data;

	return 0;
}

static int dummy_ao(comedi_device *dev,comedi_trig *it)
{
	devpriv->data=it->data[0];

	return 0;
}
